@@ -130,8 +130,6 @@ class PubInfo(object):
         return '' if info_str == '  .' else info_str
 
 
-
-
 # file extension we hope to be able to parse
 PARSEABLE_EXTENSIONS = 'txt html htm tex tei xml'.split()
 
@@ -233,7 +231,6 @@ class DublinCore(object):
         return s.strip()
 
 
-
     @staticmethod
     def make_pretty_name(name):
         """ Reverse author name components """
@@ -331,13 +328,15 @@ class DublinCore(object):
 
         return head
 
+    def append_lang(self, lang):
+        self.languages.append(lang)
 
     def add_lang_id(self, lang_id):
         """ Add language from language id. """
         language = Struct()
         language.id = lang_id
         language.language = self.language_map.get(lang_id)
-        self.languages.append(language)
+        self.append_lang(language)
 
 
     def add_author(self, name, marcrel = 'cre'):
@@ -405,6 +404,9 @@ class DublinCore(object):
 
             for elem in xpath(parser.xhtml, "/xhtml:html[@xml:lang]"):
                 self.add_lang_id(elem.get(NS.xml.lang))
+            if not self.languages:
+                for elem in xpath(parser.xhtml, "/*[@lang]"):
+                    self.add_lang_id(elem.get('lang'))
 
             for meta in xpath(parser.xhtml, "//xhtml:meta[@name='DC.Created']"):
                 self.created = gg.normalize(meta.get('content'))
@@ -506,10 +508,12 @@ class GutenbergDublinCore(DublinCore):
     def load_from_parser(self, parser):
         """ Load DublinCore from Project Gutenberg ebook.
 
-        Worst method. Use as last resort only.
-
         """
-
+        super(GutenbergDublinCore, self).load_from_parser(parser)
+        
+        ## Worst method. Use as last resort only.
+        ## first strip markup, leaving only text
+        
         for body in xpath(parser.xhtml, "//xhtml:body"):
             self.load_from_pgheader(lxml.etree.tostring(body,
                                                           encoding = six.text_type,
@@ -669,14 +673,21 @@ class GutenbergDublinCore(DublinCore):
 
         def handle_languages(self, dummy_prefix, text):
             """ Scan Language: line """
+            reset = False
             for lang in text.lower().split(','):
-                try:
-                    language = Struct()
-                    language.id = self.language_map.inverse(lang, default='en')
-                    language.language = lang.title()
-                    self.languages.append(language)
-                except KeyError:
-                    pass
+                lang = lang.strip()
+                if lang:
+                    try:
+                        language = Struct()
+                        # if language name not in our table, just keep it.
+                        language.id = self.language_map.inverse(lang, default=lang)
+                        language.language = lang.title()
+                        if not reset:
+                            self.languages = []
+                            reset = True
+                        self.append_lang(language)
+                    except KeyError:
+                        pass
 
 
         def handle_subject(self, dummy_prefix, suffix):
